pygeodesy.geodesicx

Package pygeodesy :: Package geodesicx |
[frames] | no frames]

# Package geodesicx

A pure Python version of Karney's C++ classes GeodesicExact and GeodesicLineExact.

For more details, see the C++ GeographicLib documentation, especially the Class List and the background information at Geodesics on an ellipsoid of revolution.

Also, compare `GeodesicExact` and `GeodesicLineExact` to standard classes `Geodesic` respectively `GeodesicLine` from Karney's Python implementation geographiclib, see modules pygeodesy.geodesicw and pygeodesy.karney.

Version: 25.12.23

Submodules
pygeodesy.geodesicx._C4_24: A Python version of part of Karney's C++ module GeodesicExactC4. pygeodesy.geodesicx._C4_27: A Python version of part of Karney's C++ module GeodesicExactC4. pygeodesy.geodesicx._C4_30: A Python version of part of Karney's C++ module GeodesicExactC4. pygeodesy.geodesicx.__main__: Print geodesicx version, etc. pygeodesy.geodesicx.gx: A pure Python version of Karney's C++ class GeodesicExact. pygeodesy.geodesicx.gxarea: Slightly enhanced versions of classes PolygonArea and `Accumulator` from Karney's Python geographiclib. pygeodesy.geodesicx.gxbases: (INTERNAL) Private geodesicx base class, functions and constants. pygeodesy.geodesicx.gxline: A pure Python version of Karney's C++ class GeodesicLineExact.

Classes
| GeodesicExact A pure Python version of Karney's C++ class GeodesicExact, modeled after Karney's Python class geodesic.Geodesic.
| GeodesicLineExact A pure Python version of Karney's C++ class GeodesicLineExact, modeled after Karney's Python class geodesicline.GeodesicLine.
| GeodesicAreaExact Area and perimeter of a geodesic polygon, an enhanced version of Karney's Python class PolygonArea using the more accurate surface area.
| PolygonArea For `geographiclib` compatibility, sub-class of GeodesicAreaExact.
| Caps Enum-style masks to be bit-`or`'ed to specify `geodesic`, `rhumb` or `-lines` capabilities (`caps`) and method results (`outmask`).
| GeodesicError Error raised for convergence or other issues in geodesicx, geodesicw, geodsolve or karney.